#ifndef _PYGAME2_DOCBASE_H_
#define _PYGAME2_DOCBASE_H_

#define DOC_BASE ".. note\n\nDo not use :mod:pygame2.sdlmixer and :mod:pygame2.sdl.audio at the\nsame time. As they both deal with audio hardware access, this can lead\nto problems and weird behaviour."
#define DOC_BASE_CLOSE_AUDIO "close_audio () -> None\n\nCloses an opened instance of the audio hardware.\n\nUse :func:query_spec to detect how often :func:close_audio has\nto be called.\n\nAfter calling this function (often enough), you should not invoke\nany SDL_mixer related class, method or function as they are likely\nto fail or might give unpredictable results."
#define DOC_BASE_GET_COMPILED_VERSION "get_compiled_version () -> (int, int, int)\n\nGets the SDL_mixer version pygame2 was compiled against as three-value tuple.\n\nThis version is built at compile time. It can be used to detect\nwhich features may not be available through Pygame, if it is used\nas precompiled package using a different version of the SDL_mixer\nlibrary."
#define DOC_BASE_GET_ERROR "get_error () -> str\n\nGets the last SDL_mixer error message occured.\n\nSDL_mixer maintains an internal error message. This message will\nusually be given to you when a pygame2.Error is raised.\n\nYou will rarely need to call this function."
#define DOC_BASE_GET_VERSION "get_version () -> (int, int, int)\n\nGets the SDL_mixer version pygame2 currently uses as three-value tuple.\n\nThis version is detected at runtime. It can be used to detect\nwhich features may not be available through Pygame, if it is used\nas precompiled package using a different version of the SDL_mixer\nlibrary."
#define DOC_BASE_INIT "init ([flags]) -> int\n\nInitializes the underlying SDL_mixer library.\n\nInitializes the underlying SDL_mixer library using the passed\nmixer flags. The flags indicate, which music library (FLAC, OGG,\n...) SDL_mixer should initialize and can be a bitwise\ncombination of the initialization constants of the\n:mod:pygame2.sdlmixer.constants module.\n\nIn case an error occured, an exception will be raised."
#define DOC_BASE_OPEN_AUDIO "open_audio (frequency, format, channels, chunksize) -> None\n\nInitializes the mixer API and prepares the audio hardware for access.\n\nThis must be called before using any other method or class for\naudio output. It initializes the API with a certain *frequency*\n(e.g. 44100 for 44.1 KHz).\n\n*format* is the sample format that will be used in the\nChunk and Music objects and can be one of the\n:data:AUDIO_XXX constants.\n\n*channels* denotes the number of output channels, not the number\nof Channel instances and can be 1 for mono or 2 for\nstereo sound.\n\n*chunksize* is the size of bytes used per output sample to\nstream. The larger the value, the more often the output hooks will\nbe called. A good value for chunksize is between 1024 and 4096 on\nmost computers (1kB - 4 kB).\n\n.. note\n\nYou can call this method multiple times with different\nvalues. In turn, you have to call :func:close_audio as often\nas you called :func:open_audio to shut anything down."
#define DOC_BASE_QUERY_SPEC "query_spec () -> (int, int, int, int)\n\nQueries the actual settings used by the audio device.\n\nQueries the actual settings used by the audio device and returns\nthe setting in the following order:\n\n* number of times :func:open_audio was called\n* current frequency\n* current format\n* current channel setting (stereo or mono)\n\nSee :func:open_audio for the typical meaning and values of the\nreturned tuple."
#define DOC_BASE_QUIT "quit () -> None\n\nShuts down the underlying SDL_mixer library.\n\nAfter calling this function, you should not invoke any SDL_mixer\nrelated class, method or function as they are likely to fail or\nmight give unpredictable results."
#define DOC_BASE_WAS_INIT "was_init () -> bool\n\nGets, whether the SDL_mixer library was initialized or not.\n\n.. note\n\nThis only checks, whether the **SDL** flag :data:INIT_AUDIO\nwas set."
#define DOC_BASE_CHANNEL "Channel ([index]) -> Channel\n\nCreates a new Channel for playing audio data\n\nChannel represents a playback destination for audio data.\nSDL_mixer can handle multiple channels to play audio simultanously.\n\nIf *index* is omitted or smaller than 1, a new Channel will be created.\nOtherwise Channel will refer to an existing channel and reuse it.\n\n.. note\n\nThe state of an existing channel will not be reset."
#define DOC_BASE_CHANNEL_CHUNK "The current Chunk of audio data to be played."
#define DOC_BASE_CHANNEL_FADING "The fading status of the Channel."
#define DOC_BASE_CHANNEL_PAUSED "Gets, whether the Channel playback is currently paused."
#define DOC_BASE_CHANNEL_PLAYING "Gets, whether the Channel is currently playing audio."
#define DOC_BASE_CHANNEL_VOLUME "Gets or sets the channel volume."
#define DOC_BASE_CHANNEL_EXPIRE "expire (ms) -> None\n\nHalts the playback of the Channel after *ms* milliseconds."
#define DOC_BASE_CHANNEL_FADE_IN "fade_in (sound, ms[, loops, ticks]) -> None\n\nFades in the passed sound.\n\nThis starts playing the passed *sound* at volume 0, which fades up to\nthe maximum value over *ms* milliseconds. The *sound* will be played\nfor *loops* + 1 number of times.\n\n*ticks* is the optional maximum time in milliseconds to stop playing\nafter."
#define DOC_BASE_CHANNEL_FADE_OUT "fade_out (ms) -> None\n\nFades out the current audio playback.\n\nThis gradually reduces the volume to 0 over *ms* milliseconds. The channel\nwill be halted after the fadeout is complete."
#define DOC_BASE_CHANNEL_HALT "halt () -> None\n\nStops the audio playback immediately and resets the playback state"
#define DOC_BASE_CHANNEL_PAUSE "pause () -> None\n\nPauses the current audio playback."
#define DOC_BASE_CHANNEL_PLAY "play (sound[, loops, ticks]) -> None\n\nStarts the playback of an audio Chunk.\n\nThe audio chunk will be played for *loops* + 1 times (or one time only,\nif *loops* is omitted).\n\n*ticks* is the optional maximum time in milliseconds to stop playing\nafter."
#define DOC_BASE_CHANNEL_RESUME "resume () -> None\n\nResumes the playback of a paused sound chunk."
#define DOC_BASE_CHUNK "Chunk (file) -> Chunk\n\nCreates a new sound chunk for audio playback.\n\n.. note\n\nThe file object *must* support binary read and write\naccess. This is especially important for Python 3.x users."
#define DOC_BASE_CHUNK_BUF "Gets the raw audio buffer of the Chunk."
#define DOC_BASE_CHUNK_LEN "Gets the length of the audio data."
#define DOC_BASE_CHUNK_VOLUME "Gets or sets the default volume for the audio data."
#define DOC_BASE_MUSIC "Music (file) -> Music\n\nCreates a new sound chunk for music playback.\n\n.. note\n\nThe file object *must* support binary read and write\naccess. This is especially important for Python 3.x users."
#define DOC_BASE_MUSIC_TYPE "Gets the music format."
#define DOC_BASE_MUSIC_FADE_IN "fade_in (ms[, loops, pos]) -> None\n\nFades in the Music.\n\nThis starts playing the Music at volume 0, which fades up to\nthe maximum value over *ms* milliseconds. The Music will be played\nfor *loops* + 1 number of times.\n\n*pos* is the position to start the playback from."
#define DOC_BASE_MUSIC_PLAY "play ([loops]) -> None\n\nStarts the playback of the Music.\n\nStarts the playback of the Music. The music will be played once, if\n*loops* is omitted, otherwise it will be played *loops* + 1 times."

#endif
